aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/controller
diff options
context:
space:
mode:
authorTristan Darricau <tristan.darricau@sensiolabs.com>2015-04-16 20:44:02 +0200
committerTristan Darricau <tristan.darricau@sensiolabs.com>2015-04-16 20:44:02 +0200
commitf077b72d0ddabd13350bea276069b68d5df4a89c (patch)
treed072352cd49d016b203a2e1de5464cfd9b9dd0c8 /phpBB/phpbb/controller
parentdb9ef52fdd40e2ae8118f458bd12eda540b57bd3 (diff)
parent4bdef6fd21a5dcab455b0cd1ee2652de606929c3 (diff)
downloadforums-f077b72d0ddabd13350bea276069b68d5df4a89c.tar
forums-f077b72d0ddabd13350bea276069b68d5df4a89c.tar.gz
forums-f077b72d0ddabd13350bea276069b68d5df4a89c.tar.bz2
forums-f077b72d0ddabd13350bea276069b68d5df4a89c.tar.xz
forums-f077b72d0ddabd13350bea276069b68d5df4a89c.zip
Merge pull request #3487 from MateBartus/ticket/13697
[ticket/13697] Moving filesystem related functions to filesystem service
Diffstat (limited to 'phpBB/phpbb/controller')
-rw-r--r--phpBB/phpbb/controller/helper.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/phpBB/phpbb/controller/helper.php b/phpBB/phpbb/controller/helper.php
index 340b29306a..68ccfafddf 100644
--- a/phpBB/phpbb/controller/helper.php
+++ b/phpBB/phpbb/controller/helper.php
@@ -53,7 +53,7 @@ class helper
protected $request;
/**
* @var \phpbb\filesystem The filesystem object
*/
protected $filesystem;
@@ -78,11 +78,11 @@ class helper
* @param \phpbb\routing\router $router phpBB router
* @param \phpbb\symfony_request $symfony_request Symfony Request object
* @param \phpbb\request\request_interface $request phpBB request object
* @param \phpbb\filesystem $filesystem The filesystem object
* @param string $phpbb_root_path phpBB root path
* @param string $php_ext PHP file extension
*/
- public function __construct(\phpbb\template\template $template, \phpbb\user $user, \phpbb\config\config $config, \phpbb\routing\router $router, \phpbb\symfony_request $symfony_request, \phpbb\request\request_interface $request, \phpbb\filesystem $filesystem, $phpbb_root_path, $php_ext)
+ public function __construct(\phpbb\template\template $template, \phpbb\user $user, \phpbb\config\config $config, \phpbb\routing\router $router, \phpbb\symfony_request $symfony_request, \phpbb\request\request_interface $request, \phpbb\filesystem\filesystem_interface $filesystem, $phpbb_root_path, $php_ext)
{
$this->template = $template;
$this->user = $user;
@@ -53,7 +53,7 @@ class helper
protected $request;
/**
- * @var \phpbb\filesystem The filesystem object
+ * @var \phpbb\filesystem\filesystem_interface The filesystem object
*/
protected $filesystem;
@@ -78,11 +78,11 @@ class helper
* @param \phpbb\symfony_request $symfony_request Symfony Request object
* @param \phpbb\request\request_interface $request phpBB request object
- * @param \phpbb\filesystem $filesystem The filesystem object
+ * @param \phpbb\filesystem\filesystem_interface $filesystem The filesystem object
* @param string $phpbb_root_path phpBB root path
* @param string $php_ext PHP file extension